@@ -175,7 +175,6 @@ class SupeRSS:
 
     # if no candidates, return an empty string
     if len(candidates) == 0:
-      #print "< no url found! >"
       return None
 
     # test for valid urls:
@@ -247,12 +246,12 @@ class SupeRSS:
 
   def run_concurrent(self, func, iterator):
 
-    if imported_gevent and self.concurrent:
+    if self.concurrent:
       pool = Pool(self.num_workers)
       for result in pool.imap_unordered(func, iterator):
         yield result 
 
-    elif not imported_gevent and self.concurrent:
+    elif not self.concurrent:
       logger.warn('SupeRSS requires gevent run concurrently.')
       for item in iterator:
         yield func(item)
